==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/themed_widgets/themed_setter_button.dart <==
// 🐦 Flutter imports:
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:fluent_ui/fluent_ui.dart' as fluent;
import 'package:provider/provider.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

List<Map<String, fluent.AccentColor>> accentColorNames = [
  {'orange': fluent.Colors.orange},
  {'red': fluent.Colors.red},
  {'magenta': fluent.Colors.magenta},
  {'purple': fluent.Colors.purple},
  {'blue': fluent.Colors.blue},
  {'teal': fluent.Colors.teal},
  {'green': fluent.Colors.green},
];

class ThemedSetterButton extends StatelessWidget {
  const ThemedSetterButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer<VertticeUIState>(builder: (context, value, _) {
      return fluent.Column(
        crossAxisAlignment: fluent.CrossAxisAlignment.start,
        mainAxisAlignment: fluent.MainAxisAlignment.start,
        children: [
          fluent.Text(
            'Select Accent Color',
            style: fluent.FluentTheme.of(context).typography.subtitle,
          ),
          sizedBoxH8,
          Wrap(
            children: List.generate(accentColorNames.length, (index) {
              final color = accentColorNames[index].values.first;
              return Tooltip(
                message: accentColorNames[index].keys.first,
                child: _buildColorBlock(
                  value,
                  color,
                  accentColorNames[index].keys.first,
                ),
              );
            }),
          ),
        ],
      );
    });
  }

  Widget _buildColorBlock(
      VertticeUIState value, fluent.AccentColor color, String colorName) {
    return Padding(
      padding: const EdgeInsets.all(2.0),
      child: fluent.Button(
        onPressed: () {
          value.setThemedColors(colorName);
        },
        style: fluent.ButtonStyle(
          padding: fluent.ButtonState.all(EdgeInsets.zero),
          backgroundColor: fluent.ButtonState.resolveWith((states) {
            if (states.isPressing) {
              return color.light;
            } else if (states.isHovering) {
              return color.lighter;
            }
            return color;
          }),
        ),
        child: Container(
          height: 40,
          width: 40,
          alignment: Alignment.center,
          child: value.themedColors.accentColorName == colorName
              ? Icon(
                  fluent.FluentIcons.check_mark,
                  color: color.basedOnLuminance(),
                  size: 22.0,
                )
              : null,
        ),
      ),
    );
  }
}

==> verttice_ui-0.1.2.tar.gz: lib/src/widgets/themed_widgets/themed_setter_button.dart <==
// 🐦 Flutter imports:
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:provider/provider.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

List<Map<String, Color>> accentColorNames = [
  {'orange': Colors.orange},
  {'red': Colors.red},
  {'cyan': Colors.cyan},
  {'purple': Colors.purple},
  {'blue': Colors.blue},
  {'teal': Colors.teal},
  {'green': Colors.green},
];

class ThemedSetterButton extends StatelessWidget {
  const ThemedSetterButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer<VertticeUIState>(builder: (context, value, _) {
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          const Text('Select Accent Color', style: TextStyle(fontSize: 12)),
          sizedBoxH8,
          Wrap(
            children: List.generate(accentColorNames.length, (index) {
              final color = accentColorNames[index].values.first;
              return Tooltip(
                message: accentColorNames[index].keys.first,
                child: _buildColorBlock(
                  value,
                  color,
                  accentColorNames[index].keys.first,
                ),
              );
            }),
          ),
        ],
      );
    });
  }

  Widget _buildColorBlock(
    VertticeUIState value,
    Color color,
    String colorName,
  ) {
    return Padding(
      padding: const EdgeInsets.all(2.0),
      child: ElevatedButton(
        onPressed: () {
          value.setThemedColors(colorName);
        },
        style: ButtonStyle(
          padding: MaterialStateProperty.all(EdgeInsets.zero),
          backgroundColor: MaterialStateProperty.resolveWith((states) {
            return color;
          }),
        ),
        child: Container(
          height: 40,
          width: 40,
          alignment: Alignment.center,
          child: value.themedColors.accentColorName == colorName
              ? const Icon(
                  Icons.check,
                  color: Colors.black,
                  size: 22.0,
                )
              : null,
        ),
      ),
    );
  }
}
